==> CGenius-1.7.2.0-Release-src.tar.gz: CGenius-1.7.2.0-Release-Source/CPackConfig.cmake <==
# This file will be configured to contain variables for CPack. These variables
# should be set in the CMake list file of the project before CPack module is
# included. The list of available CPACK_xxx variables and their associated
# documentation may be obtained using
#  cpack --help-variable-list
#
# Some variables are common to all generators (e.g. CPACK_PACKAGE_NAME)
# and some are specific to a generator
# (e.g. CPACK_NSIS_EXTRA_INSTALL_COMMANDS). The generator specific variables
# usually begin with CPACK_<GENNAME>_xxxx.


SET(CPACK_BINARY_BUNDLE "")
SET(CPACK_BINARY_CYGWIN "")
SET(CPACK_BINARY_DEB "")
SET(CPACK_BINARY_DRAGNDROP "")
SET(CPACK_BINARY_NSIS "")
SET(CPACK_BINARY_OSXX11 "")
SET(CPACK_BINARY_PACKAGEMAKER "")
SET(CPACK_BINARY_RPM "")
SET(CPACK_BINARY_STGZ "")
SET(CPACK_BINARY_TBZ2 "")
SET(CPACK_BINARY_TGZ "")
SET(CPACK_BINARY_TZ "")
SET(CPACK_BINARY_WIX "")
SET(CPACK_BINARY_ZIP "")
SET(CPACK_CMAKE_GENERATOR "Unix Makefiles")
SET(CPACK_COMPONENT_UNSPECIFIED_HIDDEN "TRUE")
SET(CPACK_COMPONENT_UNSPECIFIED_REQUIRED "TRUE")
SET(CPACK_DEBIAN_PACKAGE_ARCHITECTURE "amd64")
SET(CPACK_DEBIAN_PACKAGE_DEPENDS "libvorbis0a (>= 1.2.3), libvorbisenc2 (>> 1.2.3), libvorbisfile3 (>= 1.2.3), libsdl1.2debian (>= 1.2.14), libgl1-mesa-glx (>= 7.7.1), libsdl-image1.2 (>= 1.2.10-3)")
SET(CPACK_DEBIAN_PACKAGE_DESCRIPTION "The ultimate Commander Keen interpreter
 .
 Commander-Genius aka CloneKeenPlus is an engine which interprets Commander Keen 1-3 (Vorticons Series).
 .
 As fans and developers we try to implement new features, improve the game play and give the feeling, you are playing the original game.
 .
 Obviously you need the game data of the games to play it.
 Commander Keen 1 comes included in this package.
 Episode 2 and 3 are registered versions which can be purchased by 3D Realms or Apogee, or bought by someone else.
 If you still have the old games of the registered version, then give it a try. You will be surprised, how well they will look!
 Commander Keen 4 support is under heavy development. Some parts are suddenly starting to work.")
SET(CPACK_DEBIAN_PACKAGE_MAINTAINER "Gerhard Stein <gerstrong@gmail.com>")
SET(CPACK_DEBIAN_PACKAGE_NAME "CGenius")
SET(CPACK_DEBIAN_PACKAGE_SECTION "games")
SET(CPACK_GENERATOR "RPM;DEB;TGZ")
SET(CPACK_INSTALL_CMAKE_PROJECTS "/home/gerstrong/workspace/Commander-Genius;CommanderGenius;ALL;/")
SET(CPACK_INSTALL_PREFIX "/usr/local")
SET(CPACK_MODULE_PATH "/home/gerstrong/workspace/Commander-Genius/")
SET(CPACK_NSIS_DISPLAY_NAME "/usr/games")
SET(CPACK_NSIS_INSTALLER_ICON_CODE "")
SET(CPACK_NSIS_INSTALLER_MUI_ICON_CODE "")
SET(CPACK_NSIS_INSTALL_ROOT "$PROGRAMFILES")
SET(CPACK_NSIS_PACKAGE_NAME "/usr/games")
SET(CPACK_OUTPUT_CONFIG_FILE "/home/gerstrong/workspace/Commander-Genius/CPackConfig.cmake")
SET(CPACK_PACKAGE_DEFAULT_LOCATION "/")
SET(CPACK_PACKAGE_DESCRIPTION "Commander-Genius aka CloneKeenPlus is an engine which interprets Commander Keen 1-3 (Vorticons Series).
 .
 As fans and developers we try to implement new features, improve the game play and give the feeling, you are playing the original game.
 .
 Obviously you need the game data of the games to play it.
 Commander Keen 1 comes included in this package.
 Episode 2 and 3 are registered versions which can be purchased by 3D Realms or Apogee, or bought by someone else.
 If you still have the old games of the registered version, then give it a try. You will be surprised, how well they will look!
 Commander Keen 4 support is under heavy development. Some parts are suddenly starting to work.")
SET(CPACK_PACKAGE_DESCRIPTION_FILE "/home/gerstrong/workspace/Commander-Genius/README")
SET(CPACK_PACKAGE_DESCRIPTION_SUMMARY "The ultimate Commander Keen interpreter")
SET(CPACK_PACKAGE_EXECUTABLES "CGenius;Commander Genius")
SET(CPACK_PACKAGE_FILE_NAME "CGenius-1.7.2.0-Release-amd64")
SET(CPACK_PACKAGE_INSTALL_DIRECTORY "/usr/games")
SET(CPACK_PACKAGE_INSTALL_REGISTRY_KEY "/usr/games")
SET(CPACK_PACKAGE_NAME "CGenius")
SET(CPACK_PACKAGE_RELOCATABLE "true")
SET(CPACK_PACKAGE_VENDOR "The Commmander-Genius Team")
SET(CPACK_PACKAGE_VERSION "1.7.2.0-Release")
SET(CPACK_PACKAGE_VERSION_MAJOR "0")
SET(CPACK_PACKAGE_VERSION_MINOR "1")
SET(CPACK_PACKAGE_VERSION_PATCH "1")
SET(CPACK_RESOURCE_FILE_LICENSE "/home/gerstrong/workspace/Commander-Genius/COPYRIGHT")
SET(CPACK_RESOURCE_FILE_README "/usr/share/cmake-2.8/Templates/CPack.GenericDescription.txt")
SET(CPACK_RESOURCE_FILE_WELCOME "/usr/share/cmake-2.8/Templates/CPack.GenericWelcome.txt")
SET(CPACK_RPM_PACKAGE_DESCRIPTION "The ultimate Commander Keen interpreter
 .
 Commander-Genius aka CloneKeenPlus is an engine which interprets Commander Keen 1-3 (Vorticons Series).
 .
 As fans and developers we try to implement new features, improve the game play and give the feeling, you are playing the original game.
 .
 Obviously you need the game data of the games to play it.
 Commander Keen 1 comes included in this package.
 Episode 2 and 3 are registered versions which can be purchased by 3D Realms or Apogee, or bought by someone else.
 If you still have the old games of the registered version, then give it a try. You will be surprised, how well they will look!
 Commander Keen 4 support is under heavy development. Some parts are suddenly starting to work.")
SET(CPACK_RPM_PACKAGE_GROUP "Amusements/Games")
SET(CPACK_RPM_PACKAGE_LICENSE "GPL 2")
SET(CPACK_RPM_PACKAGE_NAME "CGenius")
SET(CPACK_RPM_PACKAGE_RELEASE "1")
SET(CPACK_RPM_PACKAGE_REQUIRES "SDL >= 1.2, libvorbis >= 1.3, mesa-libGL >= 7.7")
SET(CPACK_RPM_PACKAGE_SUMMARY "The ultimate Commander Keen interpreter")
SET(CPACK_RPM_PACKAGE_VENDOR "The Commmander-Genius Team")
SET(CPACK_RPM_PACKAGE_VERSION "1.7.2.0-Release")
SET(CPACK_SET_DESTDIR "OFF")
SET(CPACK_SOURCE_CYGWIN "")
SET(CPACK_SOURCE_GENERATOR "TGZ;TBZ2;TZ")
SET(CPACK_SOURCE_OUTPUT_CONFIG_FILE "/home/gerstrong/workspace/Commander-Genius/CPackSourceConfig.cmake")
SET(CPACK_SOURCE_TBZ2 "ON")
SET(CPACK_SOURCE_TGZ "ON")
SET(CPACK_SOURCE_TZ "ON")
SET(CPACK_SOURCE_ZIP "OFF")
SET(CPACK_SYSTEM_NAME "Linux")
SET(CPACK_TOPLEVEL_TAG "Linux")
SET(CPACK_WIX_SIZEOF_VOID_P "8")

==> CGenius-1.7.3.0-Release-src.tar.gz: CGenius-1.7.3.0-Release-Source/CPackConfig.cmake <==
# This file will be configured to contain variables for CPack. These variables
# should be set in the CMake list file of the project before CPack module is
# included. The list of available CPACK_xxx variables and their associated
# documentation may be obtained using
#  cpack --help-variable-list
#
# Some variables are common to all generators (e.g. CPACK_PACKAGE_NAME)
# and some are specific to a generator
# (e.g. CPACK_NSIS_EXTRA_INSTALL_COMMANDS). The generator specific variables
# usually begin with CPACK_<GENNAME>_xxxx.


SET(CPACK_BINARY_BUNDLE "")
SET(CPACK_BINARY_CYGWIN "")
SET(CPACK_BINARY_DEB "")
SET(CPACK_BINARY_DRAGNDROP "")
SET(CPACK_BINARY_NSIS "")
SET(CPACK_BINARY_OSXX11 "")
SET(CPACK_BINARY_PACKAGEMAKER "")
SET(CPACK_BINARY_RPM "")
SET(CPACK_BINARY_STGZ "")
SET(CPACK_BINARY_TBZ2 "")
SET(CPACK_BINARY_TGZ "")
SET(CPACK_BINARY_TZ "")
SET(CPACK_BINARY_WIX "")
SET(CPACK_BINARY_ZIP "")
SET(CPACK_CMAKE_GENERATOR "Unix Makefiles")
SET(CPACK_COMPONENT_UNSPECIFIED_HIDDEN "TRUE")
SET(CPACK_COMPONENT_UNSPECIFIED_REQUIRED "TRUE")
SET(CPACK_DEBIAN_PACKAGE_ARCHITECTURE "amd64")
SET(CPACK_DEBIAN_PACKAGE_DEPENDS "libvorbis0a (>= 1.2.3), libvorbisenc2 (>> 1.2.3), libvorbisfile3 (>= 1.2.3), libsdl1.2debian (>= 1.2.14), libgl1-mesa-glx (>= 7.7.1), libsdl-image1.2 (>= 1.2.10-3)")
SET(CPACK_DEBIAN_PACKAGE_DESCRIPTION "The ultimate Commander Keen interpreter
 .
 Commander-Genius aka CloneKeenPlus is an engine which interprets Commander Keen 1-6 (Vorticons and Galaxy Series).
 .
 As fans and developers we try to implement new features, improve the gameplay and give the feeling, you are playing the original game.
 .
 Obviously you need the game data of the games to play it.
 Commander Keen 1 and 4 come included in this package.
 Episode 2, 3, 5 and 6 are registered versions which can be purchased by 3D Realms or Apogee, or bought by someone else.
 If you still have the old games of the registered version, then give it a try. You will be surprised, how well they will look!
")
SET(CPACK_DEBIAN_PACKAGE_MAINTAINER "Gerhard Stein <gerstrong@gmail.com>")
SET(CPACK_DEBIAN_PACKAGE_NAME "CGenius")
SET(CPACK_DEBIAN_PACKAGE_SECTION "games")
SET(CPACK_GENERATOR "RPM;DEB;TGZ")
SET(CPACK_INSTALL_CMAKE_PROJECTS "/home/gerstrong/workspace/Commander-Genius;CommanderGenius;ALL;/")
SET(CPACK_INSTALL_PREFIX "/usr/local")
SET(CPACK_MODULE_PATH "/home/gerstrong/workspace/Commander-Genius/")
SET(CPACK_NSIS_DISPLAY_NAME "/usr/games")
SET(CPACK_NSIS_INSTALLER_ICON_CODE "")
SET(CPACK_NSIS_INSTALLER_MUI_ICON_CODE "")
SET(CPACK_NSIS_INSTALL_ROOT "$PROGRAMFILES")
SET(CPACK_NSIS_PACKAGE_NAME "/usr/games")
SET(CPACK_OUTPUT_CONFIG_FILE "/home/gerstrong/workspace/Commander-Genius/CPackConfig.cmake")
SET(CPACK_PACKAGE_DEFAULT_LOCATION "/")
SET(CPACK_PACKAGE_DESCRIPTION "Commander-Genius aka CloneKeenPlus is an engine which interprets Commander Keen 1-6 (Vorticons and Galaxy Series).
 .
 As fans and developers we try to implement new features, improve the gameplay and give the feeling, you are playing the original game.
 .
 Obviously you need the game data of the games to play it.
 Commander Keen 1 and 4 come included in this package.
 Episode 2, 3, 5 and 6 are registered versions which can be purchased by 3D Realms or Apogee, or bought by someone else.
 If you still have the old games of the registered version, then give it a try. You will be surprised, how well they will look!
")
SET(CPACK_PACKAGE_DESCRIPTION_FILE "/home/gerstrong/workspace/Commander-Genius/README")
SET(CPACK_PACKAGE_DESCRIPTION_SUMMARY "The ultimate Commander Keen interpreter")
SET(CPACK_PACKAGE_EXECUTABLES "CGenius;Commander Genius")
SET(CPACK_PACKAGE_FILE_NAME "CGenius-1.7.3.0-Release-amd64")
SET(CPACK_PACKAGE_INSTALL_DIRECTORY "/usr/games")
SET(CPACK_PACKAGE_INSTALL_REGISTRY_KEY "/usr/games")
SET(CPACK_PACKAGE_NAME "CGenius")
SET(CPACK_PACKAGE_RELOCATABLE "true")
SET(CPACK_PACKAGE_VENDOR "The Commmander-Genius Team")
SET(CPACK_PACKAGE_VERSION "1.7.3.0-Release")
SET(CPACK_PACKAGE_VERSION_MAJOR "0")
SET(CPACK_PACKAGE_VERSION_MINOR "1")
SET(CPACK_PACKAGE_VERSION_PATCH "1")
SET(CPACK_RESOURCE_FILE_LICENSE "/home/gerstrong/workspace/Commander-Genius/COPYRIGHT")
SET(CPACK_RESOURCE_FILE_README "/usr/share/cmake-2.8/Templates/CPack.GenericDescription.txt")
SET(CPACK_RESOURCE_FILE_WELCOME "/usr/share/cmake-2.8/Templates/CPack.GenericWelcome.txt")
SET(CPACK_RPM_PACKAGE_DESCRIPTION "The ultimate Commander Keen interpreter
 .
 Commander-Genius aka CloneKeenPlus is an engine which interprets Commander Keen 1-6 (Vorticons and Galaxy Series).
 .
 As fans and developers we try to implement new features, improve the gameplay and give the feeling, you are playing the original game.
 .
 Obviously you need the game data of the games to play it.
 Commander Keen 1 and 4 come included in this package.
 Episode 2, 3, 5 and 6 are registered versions which can be purchased by 3D Realms or Apogee, or bought by someone else.
 If you still have the old games of the registered version, then give it a try. You will be surprised, how well they will look!
")
SET(CPACK_RPM_PACKAGE_GROUP "Amusements/Games")
SET(CPACK_RPM_PACKAGE_LICENSE "GPL 2")
SET(CPACK_RPM_PACKAGE_NAME "CGenius")
SET(CPACK_RPM_PACKAGE_RELEASE "1")
SET(CPACK_RPM_PACKAGE_REQUIRES "SDL >= 1.2, libvorbis >= 1.3, mesa-libGL >= 7.7")
SET(CPACK_RPM_PACKAGE_SUMMARY "The ultimate Commander Keen interpreter")
SET(CPACK_RPM_PACKAGE_VENDOR "The Commmander-Genius Team")
SET(CPACK_RPM_PACKAGE_VERSION "1.7.3.0-Release")
SET(CPACK_SET_DESTDIR "OFF")
SET(CPACK_SOURCE_CYGWIN "")
SET(CPACK_SOURCE_GENERATOR "TGZ;TBZ2;TZ")
SET(CPACK_SOURCE_OUTPUT_CONFIG_FILE "/home/gerstrong/workspace/Commander-Genius/CPackSourceConfig.cmake")
SET(CPACK_SOURCE_TBZ2 "ON")
SET(CPACK_SOURCE_TGZ "ON")
SET(CPACK_SOURCE_TZ "ON")
SET(CPACK_SOURCE_ZIP "OFF")
SET(CPACK_SYSTEM_NAME "Linux")
SET(CPACK_TOPLEVEL_TAG "Linux")
SET(CPACK_WIX_SIZEOF_VOID_P "8")
